==> 0.0.2.tar.gz: lib/flutter_color_buttons.dart <==
// ignore_for_file: must_be_immutable

library flutter_buttons;

import 'package:flutter/material.dart';

class BlueButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  BlueButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.blue, primary: Colors.black), //ripple color
        child: const Text(
          'Click !',
        ));
  }
}

class RedButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  RedButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.red, primary: Colors.black), //ripple color
        child: const Text(
          'Click !',
        ));
  }
}

class YellowButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  YellowButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.yellow,
            primary: Colors.black), //ripple color
        child: const Text(
          'Click !',
        ));
  }
}

class GreenButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  GreenButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.green,
            primary: Colors.black), //ripple color
        child: const Text(
          'Click !',
        ));
  }
}

class GreyButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  GreyButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.grey, primary: Colors.black), //ripple color
        child: const Text(
          'Click !',
        ));
  }
}

class PinkButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  PinkButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.pink, primary: Colors.black), //ripple color
        child: const Text(
          'Click !',
        ));
  }
}

class PurpleButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  PurpleButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.purple,
            primary: Colors.black), //ripple color
        child: const Text(
          'Click !',
        ));
  }
}

class IndigoButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  IndigoButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.indigo,
            primary: Colors.black), //ripple color
        child: const Text(
          'Click !',
        ));
  }
}

class AmberButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  AmberButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.amber,
            primary: Colors.black), //ripple color
        child: const Text(
          'Click !',
        ));
  }
}

class CyanButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  CyanButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.cyan, primary: Colors.black), //ripple color
        child: const Text(
          'Click !',
        ));
  }
}

class OrangeButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  OrangeButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.orange,
            primary: Colors.black), //ripple color
        child: const Text(
          'Click !',
        ));
  }
}

class TealButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  TealButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.teal, primary: Colors.black), //ripple color
        child: const Text(
          'Click !',
        ));
  }
}

class LimeButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  LimeButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.limeAccent,
            primary: Colors.black), //ripple color
        child: const Text(
          'Click !',
        ));
  }
}

class BrownButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  BrownButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.brown,
            primary: Colors.black), //ripple color
        child: const Text(
          'Click !',
        ));
  }
}

class WhiteButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  WhiteButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.white,
            primary: Colors.black), //ripple color
        child: const Text(
          'Click !',
        ));
  }
}

==> 0.0.5.tar.gz: lib/flutter_color_buttons.dart <==
// ignore_for_file: must_be_immutable

library flutter_buttons;

import 'package:flutter/material.dart';

class BlueButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  BlueButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.blue, primary: Colors.black), //ripple color
        child: const Text(
          'BlueButton',
        ));
  }
}

class RedButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  RedButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.red, primary: Colors.black), //ripple color
        child: const Text(
          'RedButton',
        ));
  }
}

class YellowButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  YellowButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.yellow,
            primary: Colors.black), //ripple color
        child: const Text(
          'YellowButton',
        ));
  }
}

class GreenButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  GreenButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.green,
            primary: Colors.black), //ripple color
        child: const Text(
          'GreenButton',
        ));
  }
}

class GreyButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  GreyButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.grey, primary: Colors.black), //ripple color
        child: const Text(
          'GreyButton',
        ));
  }
}

class PinkButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  PinkButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.pink, primary: Colors.black), //ripple color
        child: const Text(
          'PinkButton',
        ));
  }
}

class PurpleButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  PurpleButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.purple,
            primary: Colors.black), //ripple color
        child: const Text(
          'PurpleButton',
        ));
  }
}

class IndigoButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  IndigoButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.indigo,
            primary: Colors.black), //ripple color
        child: const Text(
          'IndigoButton',
        ));
  }
}

class AmberButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  AmberButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.amber,
            primary: Colors.black), //ripple color
        child: const Text(
          'AmberButton',
        ));
  }
}

class CyanButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  CyanButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.cyan, primary: Colors.black), //ripple color
        child: const Text(
          'CyanButton',
        ));
  }
}

class OrangeButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  OrangeButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.orange,
            primary: Colors.black), //ripple color
        child: const Text(
          'OrangeButton',
        ));
  }
}

class TealButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  TealButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.teal, primary: Colors.black), //ripple color
        child: const Text(
          'TealButton',
        ));
  }
}

class LimeButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  LimeButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.limeAccent,
            primary: Colors.black), //ripple color
        child: const Text(
          'LimeButton',
        ));
  }
}

class BrownButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  BrownButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: Colors.brown,
            primary: Colors.black), //ripple color
        child: const Text(
          'BrownButton',
        ));
  }
}

class CedarButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  CedarButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: const Color(0xff4b3a26),
            primary: Colors.black), //ripple color
        child: const Text(
          'CedarButton',
        ));
  }
}

class OrchidButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  OrchidButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: const Color(0xffaf69ee),
            primary: Colors.black), //ripple color
        child: const Text(
          'OrchidButton',
        ));
  }
}

class SyrupButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  SyrupButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: const Color(0xff492000),
            primary: Colors.black), //ripple color
        child: const Text(
          'SyrupButton',
        ));
  }
}

class TurkishButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  TurkishButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: const Color(0xff5097a4),
            primary: Colors.black), //ripple color
        child: const Text(
          'TurkishButton',
        ));
  }
}

class MintButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  MintButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: const Color(0xff98fb98),
            primary: Colors.black), //ripple color
        child: const Text(
          'MintButton',
        ));
  }
}

class RoyalButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  RoyalButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: const Color(0xff7852a9),
            primary: Colors.black), //ripple color
        child: const Text(
          'RoyalButton',
        ));
  }
}

class EmeraldButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  EmeraldButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: const Color(0xff50c878),
            primary: Colors.black), //ripple color
        child: const Text(
          'EmeraldButton',
        ));
  }
}

class CornflowerButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  CornflowerButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: const Color(0xff6693f5),
            primary: Colors.black), //ripple color
        child: const Text(
          'CornflowerButton',
        ));
  }
}

class CarmineButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  CarmineButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: const Color(0xff960019),
            primary: Colors.black), //ripple color
        child: const Text(
          'CarmineButton',
        ));
  }
}

class FerrariButton extends StatelessWidget {
  dynamic onPressed;
  final Widget child;
  dynamic style;
  FerrariButton(
      {Key? key, @required this.onPressed, required this.child, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        onPressed: () {},
        style: TextButton.styleFrom(
            backgroundColor: const Color(0xffff2800),
            primary: Colors.black), //ripple color
        child: const Text(
          'FerrariButton',
        ));
  }
}
